@@ -17,8 +17,9 @@ LOGGER = get_logger(name="polarion-verify-tc-requirements")
     default=os.path.expanduser("~/.config/python-utility-scripts/config.yaml"),
 )
 @click.option("--project-id", "-p", help="Provide the polarion project id")
+@click.option("--branch", "-b", help="Provide the github remote branch to run against", default="origin/main")
 @click.option("--verbose", default=False, is_flag=True)
-def has_verify(config_file_path: str, project_id: str, verbose: bool) -> None:
+def has_verify(config_file_path: str, project_id: str, branch: str, verbose: bool) -> None:
     if verbose:
         LOGGER.setLevel(logging.INFO)
     else:
@@ -26,7 +27,7 @@ def has_verify(config_file_path: str, project_id: str, verbose: bool) -> None:
     polarion_project_id = project_id or get_polarion_project_id(
         config_file_path=config_file_path, util_name="pyutils-polarion-verify-tc-requirements"
     )
-    if added_ids := find_polarion_ids(polarion_project_id=polarion_project_id, string_to_match="added"):
+    if added_ids := find_polarion_ids(polarion_project_id=polarion_project_id, string_to_match="added", branch=branch):
         LOGGER.info(f"Checking following ids: {added_ids}")
         if tests_with_missing_requirements := validate_polarion_requirements(
             polarion_test_ids=added_ids,
